==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AConstantImmediate.h <==
// public final class soot.jimple.parser.node.AConstantImmediate

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d926acb6e991836f soot_jimple_parser_node_AConstantImmediate
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e5ba3870b9b1dbcc soot_jimple_parser_node_PImmediate

// header file dependencies
// @dep_header soot_jimple_parser_node_PImmediate

#include "soot/jimple/parser/node/PImmediate.h"

#ifndef _JC_soot_jimple_parser_node_AConstantImmediate_H_
#define _JC_soot_jimple_parser_node_AConstantImmediate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PConstant$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs	_jc_soot_jimple_parser_node_AConstantImmediate$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs	_jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$refs	_jc_soot_jimple_parser_node_AConstantImmediate$refs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$nonrefs	_jc_soot_jimple_parser_node_AConstantImmediate$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$object	_jc_soot_jimple_parser_node_AConstantImmediate$object;

typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vmethods	_jc_soot_jimple_parser_node_AConstantImmediate$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vtable	_jc_soot_jimple_parser_node_AConstantImmediate$vtable;
typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vtype	_jc_soot_jimple_parser_node_AConstantImmediate$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$_init$3f8b86dec3c064c0(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
extern struct _jc_soot_jimple_parser_node_PConstant$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$getConstant$cf1afdf6e46e3a31(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$setConstant$4d9148d21934f1ac(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$getConstant$cf1afdf6e46e3a31;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$setConstant$4d9148d21934f1ac;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AConstantImmediate$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
	struct _jc_soot_jimple_parser_node_PConstant$object	*(*getConstant$cf1afdf6e46e3a31)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setConstant$4d9148d21934f1ac)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AConstantImmediate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PImmediate$vmethods	soot_jimple_parser_node_PImmediate;
	_jc_soot_jimple_parser_node_AConstantImmediate$vmethods	soot_jimple_parser_node_AConstantImmediate;
};

// Vtype
struct _jc_soot_jimple_parser_node_AConstantImmediate$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AConstantImmediate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs {
	struct _jc_soot_jimple_parser_node_PConstant$object	*__5fconstant__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AConstantImmediate$refs {
    _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs	soot_jimple_parser_node_AConstantImmediate;
    _jc_soot_jimple_parser_node_PImmediate$sub_refs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AConstantImmediate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PImmediate$sub_nonrefs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs	soot_jimple_parser_node_AConstantImmediate;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AConstantImmediate$object {
	_jc_soot_jimple_parser_node_AConstantImmediate$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AConstantImmediate$vtype	*vtype;
	_jc_soot_jimple_parser_node_AConstantImmediate$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AConstantImmediate$vtype _jc_soot_jimple_parser_node_AConstantImmediate$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AConstantImmediate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AConstantImmediate$class_object;

#endif	/* _JC_soot_jimple_parser_node_AConstantImmediate_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AConstantImmediate.h <==
// public final class soot.jimple.parser.node.AConstantImmediate

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d926acb6e991836f soot_jimple_parser_node_AConstantImmediate
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e5ba3870b9b1dbcc soot_jimple_parser_node_PImmediate

// header file dependencies
// @dep_header soot_jimple_parser_node_PImmediate

#include "soot/jimple/parser/node/PImmediate.h"

#ifndef _JC_soot_jimple_parser_node_AConstantImmediate_H_
#define _JC_soot_jimple_parser_node_AConstantImmediate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PConstant$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs	_jc_soot_jimple_parser_node_AConstantImmediate$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs	_jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$refs	_jc_soot_jimple_parser_node_AConstantImmediate$refs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$nonrefs	_jc_soot_jimple_parser_node_AConstantImmediate$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AConstantImmediate$object	_jc_soot_jimple_parser_node_AConstantImmediate$object;

typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vmethods	_jc_soot_jimple_parser_node_AConstantImmediate$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vtable	_jc_soot_jimple_parser_node_AConstantImmediate$vtable;
typedef const struct _jc_soot_jimple_parser_node_AConstantImmediate$vtype	_jc_soot_jimple_parser_node_AConstantImmediate$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$_init$3f8b86dec3c064c0(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PConstant$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$getConstant$cf1afdf6e46e3a31(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AConstantImmediate$method$setConstant$4d9148d21934f1ac(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AConstantImmediate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$getConstant$cf1afdf6e46e3a31;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$setConstant$4d9148d21934f1ac;
extern _jc_method _jc_soot_jimple_parser_node_AConstantImmediate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AConstantImmediate$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PConstant$object	*(*getConstant$cf1afdf6e46e3a31)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setConstant$4d9148d21934f1ac)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *, struct _jc_soot_jimple_parser_node_PConstant$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AConstantImmediate$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AConstantImmediate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PImmediate$vmethods	soot_jimple_parser_node_PImmediate;
	_jc_soot_jimple_parser_node_AConstantImmediate$vmethods	soot_jimple_parser_node_AConstantImmediate;
};

// Vtype
struct _jc_soot_jimple_parser_node_AConstantImmediate$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AConstantImmediate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs {
	struct _jc_soot_jimple_parser_node_PConstant$object	*__5fconstant__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AConstantImmediate$refs {
    _jc_soot_jimple_parser_node_AConstantImmediate$sub_refs	soot_jimple_parser_node_AConstantImmediate;
    _jc_soot_jimple_parser_node_PImmediate$sub_refs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AConstantImmediate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PImmediate$sub_nonrefs	soot_jimple_parser_node_PImmediate;
    _jc_soot_jimple_parser_node_AConstantImmediate$sub_nonrefs	soot_jimple_parser_node_AConstantImmediate;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AConstantImmediate$object {
	_jc_soot_jimple_parser_node_AConstantImmediate$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AConstantImmediate$vtype	*vtype;
	_jc_soot_jimple_parser_node_AConstantImmediate$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AConstantImmediate$vtype _jc_soot_jimple_parser_node_AConstantImmediate$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AConstantImmediate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AConstantImmediate$class_object;

#endif	/* _JC_soot_jimple_parser_node_AConstantImmediate_H_ */
